---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: 'feature'
assignees: ''

---

**Feature description**

Describe the feature

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context about the problem here.

**Possible implementation**
Preliminary ideas to get this done.
If you have all details in mind then provide a checklist

- [ ] Start with ...
- [ ] When done do ...
- [ ] Finally ...
